SetFactory("OpenCASCADE"); // use OpenCASCADE kernel si besoin (CSG)

// Paramtres pour le modle : dimensions en m!!!

Lx1 = 1000;		// Lx du Substrat (lame de verre), couche 1
Ly1 = 1000;		// Ly du Substrat
Lz1 = 500;		// Lz du Substrat

Lx2 = 500;		// Lx de la couche 2 (PMMA)
Ly2 = 500;		// Ly de la couche 2
Lz2 = 50;		// Lz de la couche 2

Lx3 = 150;		// Lx de la couche 3 (Chrome)
Ly3 = 150;		// Ly de la couche 3
Lz3 = 0.05;		// Lz de la couche 3

Mesh.Algorithm = 6;
lc1 = ((Lx1+Ly1+Lz1)/3)/15;			// Taille lment couche 1 (substrat)
lc2 = ((Lx2+Ly2+Lz2)/3)/10;			// Taille lment couche 2 (PMMA)
lc3 = lc2/7;					// Taille lment MAX de la couche 3 (Chrome)
lcmin = Lz3/3;					// Taille lment MIN de la couche 3 (Chrome)

dmax1 = Sqrt(Lx1*Lx1+Ly1*Ly1+Lz1*Lz1)/3;	// Distance max couche 1 par rapport  l'excitation centrale
dX1 = Abs(Lx1);dY1 = Abs(Ly1); dZ1=Abs(Lz1);
dmax2 = Sqrt(Lx2*Lx2+Ly2*Ly2+Lz2*Lz2)/3;	// Distance max couche 2 par rapport  l'excitation centrale
dX2 = Abs(Lx2);dY2 = Abs(Ly2); dZ2=Abs(Lz2);
dmax3 = Sqrt(Lx3*Lx3+Ly3*Ly3+Lz3*Lz3)/3;	// Distance max couche 3 par rapport  l'excitation centrale
dX3 = Abs(Lx3);dY3 = Abs(Ly3); dZ3=Abs(Lz3);

// *********** GEOMETRIE et PHYSIQUE ***********

Box(1) = {0, 0, 0, Lx1, Ly1, Lz1};
Box(2) = {(Lx1-Lx2)/2, (Ly1-Ly2)/2, Lz1, Lx2, Ly2, Lz2};
Box(3) = {(Lx1-Lx3)/2, (Ly1-Ly3)/2, Lz1+Lz2, Lx3, Ly3, Lz3};
BooleanFragments{ Volume{1,2,3}; Delete; }{}
Translate {-Lx1/2,-Ly1/2,-(Lz1+Lz2+Lz3)} { Volume{1,2,3}; }
Coherence;

Characteristic Length{ PointsOf{ Surface{47}; } } = lc3;
Characteristic Length{ PointsOf{ Surface{41}; } } = lc2;
Characteristic Length{ PointsOf{ Surface{42}; } } = lc3;

Characteristic Length{ PointsOf{ Surface{35}; } } = lc1;
Characteristic Length{ PointsOf{ Surface{36}; } } = lc2;
Characteristic Length{ PointsOf{ Surface{34}; } } = lc1;

// Mesh size by MathEval
//----------------------
Field[1] = MathEval;
Field[1].F = Sprintf( "%g + (%g-%g)/%g*Sqrt(x*x+y*y+z*z)", lcmin, lc2, lcmin, dmax2);

Background Field = 1;

// ---------------------
Mesh.Format=1;
// Select older mesh version, for compatibility of FF++
//Mesh.MshFileVersion = 2.2;
// ---------------------

Mesh 3;
Coherence Mesh;

// ****************************************
// ********** ENTITES PHYSIQUES ***********
// ****************************************

//----------------------
Physical Volume(1) = {1};	// Rgion du substrat
Physical Volume(2) = {2};	// Rgion du PMMA
Physical Volume(3) = {3};	// Rgion du Chrome (excitation volumique)
Physical Surface(4) = {47};	// Surface de dessus du Chrome (excitation surfacique)
Physical Surface(5) = {34};	// Surface du dessous du substrat
